==> haskell-data-clist-0.2-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-1Q3dBPxEFZlFPtiPwL3SPc
key:                  data-clist-0.2-1Q3dBPxEFZlFPtiPwL3SPc
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  7743d793fe031aacce86b9ef105a43c3
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-1Q3dBPxEFZlFPtiPwL3SPc
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.2-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-DHncy0ZPRs9tBx1G7TfcR
key:                  data-clist-0.2-DHncy0ZPRs9tBx1G7TfcR
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  46a0355db00b45aa6dc382b30fa0bbf0
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-DHncy0ZPRs9tBx1G7TfcR
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
